@@ -6,7 +6,7 @@ from pydantic import BaseModel
 
 from getdeck.configuration import ClientConfiguration
 from getdeck.deckfile.errors import DeckfileError
-from getdeck.provider.abstract import AbstractK8sProvider
+from getdeck.provider.abstract import AbstractProvider
 
 logger = logging.getLogger("deck")
 
@@ -17,19 +17,19 @@ class DeckfileCluster(BaseModel):
     name: str
     nativeConfig: dict = None
 
-    def get_provider(self, config: ClientConfiguration) -> AbstractK8sProvider:
-        from getdeck.provider.factory import kubernetes_cluster_factory
-        from getdeck.provider.types import K8sProviderType
+    def get_provider(self, config: ClientConfiguration) -> AbstractProvider:
+        from getdeck.provider.factory import cluster_factory
+        from getdeck.provider.types import ProviderType
 
         # get selected kubernetes cluster from factory
         try:
-            kubernetes_cluster = kubernetes_cluster_factory.get(
-                K8sProviderType(self.provider.lower()),
+            cluster = cluster_factory.get(
+                ProviderType(self.provider.lower()),
                 config,
                 name=self.name,
                 native_config=self.nativeConfig,
             )
-            return kubernetes_cluster
+            return cluster
         except Exception as e:
             logger.error(e)
             raise e
@@ -39,6 +39,7 @@ class DeckfileHelmSource(BaseModel):
     type: str = "helm"
     ref: str
     targetRevision: str = ""
+    namespace: str = ""
     path: str = None
     chart: str = None  # this is set when pulling directly from a Helm repo
     parameters: List[Dict] = None  # Helm value overrides (take precedence)
@@ -75,6 +76,7 @@ class DeckfileDeck(BaseModel):
     name: str
     namespace: str = "default"
     notes: str = ""
+    hosts: List[str] = []
     sources: List[
         Union[
             DeckfileHelmSource,
@@ -115,5 +117,5 @@ class Deckfile(ABC):
         raise NotImplementedError
 
     @abstractmethod
-    def get_deck(self) -> DeckfileDeck:
+    def get_deck(self, name: str = None) -> DeckfileDeck:
         raise NotImplementedError
